@@ -32,7 +32,7 @@ class MenuModel::Private {
 public:
     Private() {}
 
-    MenuItem *rootItem;
+    MenuItem *rootItem = nullptr;
     QList<MenuItem*> exceptions;
 };
 
@@ -69,7 +69,7 @@ int MenuModel::rowCount( const QModelIndex &parent ) const
 
 QVariant MenuModel::data( const QModelIndex &index, int role ) const
 {
-    MenuItem * mi = 0;
+    MenuItem * mi = nullptr;
     QVariant theData;
     if ( !index.isValid() ) {
         return QVariant();
@@ -88,7 +88,7 @@ QVariant MenuModel::data( const QModelIndex &index, int role ) const
             break;
         case KCategorizedSortFilterProxyModel::CategorySortRole:
             if ( mi->parent() ) {
-                theData.setValue( QString("%1%2").arg( QString::number(mi->parent()->weight()), 5, '0' ).arg( mi->parent()->name() ) );
+                theData.setValue( QStringLiteral("%1%2").arg( QString::number(mi->parent()->weight()), 5, QLatin1Char('0') ).arg( mi->parent()->name() ) );
             }
             break;
         case KCategorizedSortFilterProxyModel::CategoryDisplayRole:
@@ -103,7 +103,7 @@ QVariant MenuModel::data( const QModelIndex &index, int role ) const
             theData.setValue( mi->keywords().join( QString() ) );
             break;
         case MenuModel::UserSortRole:
-            theData.setValue( QString("%1").arg( QString::number(mi->weight()), 5, '0' ) );
+            theData.setValue( QStringLiteral("%1").arg( QString::number(mi->weight()), 5, QLatin1Char('0') ) );
             break;
         default:
             break;
@@ -114,7 +114,7 @@ QVariant MenuModel::data( const QModelIndex &index, int role ) const
 Qt::ItemFlags MenuModel::flags( const QModelIndex &index ) const
 {
     if ( !index.isValid() ) {
-        return 0;
+        return nullptr;
     }
 
     return Qt::ItemIsEnabled | Qt::ItemIsSelectable;
