@@ -185,6 +185,8 @@ public:
             KService::Ptr service = KService::serviceByStorageId(desktopName);
 
             if (!service || !service->isValid()) {
+                qWarning()<<desktopName;
+                m_resultModel->forgetResource(QStringLiteral("kcm:") % desktopName);
                 return QVariant();
             }
             mi->setService(service);
@@ -481,6 +483,12 @@ void SidebarMode::initWidget()
 
     d->quickWidget->setSource(QUrl::fromLocalFile(d->package.filePath("mainscript")));
 
+    if (!d->quickWidget->rootObject()) {
+        for (const auto &err : d->quickWidget->errors()) {
+            qWarning() << err.toString();
+        }
+        qFatal("Fatal error while loading the sidebar view qml component");
+    }
     const int rootImplicitWidth = d->quickWidget->rootObject()->property("implicitWidth").toInt();
     if (rootImplicitWidth != 0) {
         d->quickWidget->setFixedWidth(rootImplicitWidth);
